flash_encryption

Function flash_encryption 

pub fn flash_encryption() -> bool
Available on crate feature unstable only.
Get status of SPI boot encryption.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.