major_chip_version

Function major_chip_version 

pub fn major_chip_version() -> u8
Available on crate feature unstable only.
Returns the major hardware revision

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.