minor_chip_version

Function minor_chip_version 

pub fn minor_chip_version() -> u8
Available on crate feature unstable only.
Returns the minor hardware revision

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.