read_bit

Function read_bit 

pub fn read_bit(field: EfuseField) -> bool
Available on crate feature unstable only.
Read bit value.

This function panics if the field’s bit length is not equal to 1.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.