read_field_le

Function read_field_le 

pub fn read_field_le<T: AnyBitPattern>(field: EfuseField) -> T
Available on crate feature unstable only.
Read field value in a little-endian order

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.