rtc_calib_cal_code

Function rtc_calib_cal_code 

pub fn rtc_calib_cal_code(
    _unit: AdcCalibUnit,
    atten: Attenuation,
) -> Option<u16>
Available on crate feature unstable only.
Get ADC reference point digital code for specified attenuation

see https://github.com/espressif/esp-idf/blob/903af13e8/components/efuse/esp32c6/esp_efuse_rtc_calib.c#L42

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.