rtc_calib_version

Function rtc_calib_version 

pub fn rtc_calib_version() -> u8
Available on crate feature unstable only.
Get version of RTC calibration block

see https://github.com/espressif/esp-idf/blob/903af13e8/components/efuse/esp32c6/esp_efuse_rtc_calib.c#L20

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.