rwdt_multiplier

Function rwdt_multiplier 

pub fn rwdt_multiplier() -> u8
Available on crate feature unstable only.
Get the multiplier for the timeout value of the RWDT STAGE 0 register.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.