pub struct ChipRevision {
pub major: u8,
pub minor: u8,
}Expand description
Represents the hardware revision.
The type supports converting between two separate u16-based representations:
- Combined: a
u16calculated asmajor * 100 + minor. The combined representation is more often used by ESP-IDF, and working with it involves integer division. Note that the combined representation assumes minor is less than 100. - Packed: a
u16with the major revision in the high byte and the minor revision in the low byte.
Examples
use esp_hal::efuse::ChipRevision;
let rev = esp_hal::efuse::chip_revision();
println!("Chip revision: {}.{}", rev.major, rev.minor);
// You can compare against other ChipRevision objects
if rev < ChipRevision::from_combined(300) {
// You can print a debug representation
println!("Chip revision is too old: {:?}", rev);
}
if rev >= ChipRevision::from_packed(0x400) {
println!("Chip revision is too new: {:?}", rev);
}
// You can convert into two different numeric representations.
assert!(rev.packed() >= 0x300);
assert!(rev.combined() >= 300);Fields
major: u8The major revision number.
minor: u8The minor revision number.
Implementations
Sourceimpl ChipRevision
impl ChipRevision
Sourcepub const fn from_combined(revision: u16) -> Self
pub const fn from_combined(revision: u16) -> Self
Creates a new ChipRevision from a combined revision value.
Sourcepub const fn combined(self) -> u16
pub const fn combined(self) -> u16
Returns the combined revision value as a u16.
The combined revision value is a u16 calculated as major * 100 + minor.
Sourcepub const fn from_packed(packed: u16) -> Self
pub const fn from_packed(packed: u16) -> Self
Creates a new ChipRevision from a packed revision value.
The packed revision value is a u16 with the major revision in the high byte and the minor
revision in the low byte.