MacAddress

Struct MacAddress 

pub struct MacAddress(/* private fields */);
Hardware (MAC) address.

Use as_bytes for raw access, or the Display impl for colon-separated hex (e.g. aa:bb:cc:dd:ee:ff).

Implementations

Source

impl MacAddress

pub const fn new_eui48(bytes: [u8; 6]) -> Self

Available on crate feature unstable only.

Creates a new MacAddress from the given bytes.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn as_bytes(&self) -> &[u8]

Returns the address bytes.