Enum AdcCalibUnit Copy item path Source pub enum AdcCalibUnit {
ADC1,
ADC2,
}Available on crate feature unstable only.
Expand description Selects which ADC we are interested in the efuse calibration data for
 Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Select efuse calibration data for ADC1
Select efuse calibration data for ADC2
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.