pub enum SetMacError {
AlreadySet,
}Available on crate feature
unstable only.Expand description
Error indicating issues with setting the MAC address.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Variants
AlreadySet
The MAC address has already been set and cannot be changed.