pub fn base_mac_address() -> MacAddressAvailable on crate feature
unstable only.Expand description
Returns the base MAC address programmed into eFuse during manufacturing.
This always reads directly from the hardware eFuse storage. To get the
effective MAC for a specific radio interface (which may be overridden via
override_mac_address), use interface_mac_address instead.
Example
use esp_hal::efuse;
let mac = efuse::base_mac_address();
println!("Base MAC: {mac}");Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.