pub fn override_mac_address(mac: MacAddress) -> Result<(), SetMacError>Available on crate feature
unstable only.Expand description
Overrides the base MAC address used by interface_mac_address.
After a successful call, interface_mac_address will derive
per-interface addresses from the overridden base instead of the factory
eFuse MAC. base_mac_address is unaffected and continues to return the
factory eFuse value.
The override does not persist across device resets.
Can only be called once. Returns Err(SetMacError::AlreadySet)
otherwise.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.