pub struct MacAddress(/* private fields */);Expand description
Implementations
Sourceimpl MacAddress
impl MacAddress
Sourcepub const fn new_eui48(bytes: [u8; 6]) -> Self
Available on crate feature unstable only.
pub const fn new_eui48(bytes: [u8; 6]) -> Self
unstable only.Creates a new MacAddress from the given bytes.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.